@@ -184,7 +184,7 @@ Table information is inherited by subclasses, but can be overridden.
   $sequence_name = $obj->sequence;
 
 If you are using a database which supports sequences, then you should
-declare this using the sequence() method. 
+declare this using the sequence() method.
 
     __PACKAGE__->columns(Primary => 'id');
     __PACKAGE__->sequence('class_id_seq');
@@ -304,8 +304,9 @@ is used.
 
   $obj->delete;
 
-Deletes this object from the database and from memory.  $obj is no longer
-usable after this call.
+Deletes this object from the database and from memory. If you have set
+up any relationships using hasa_list, delete the foreign elements also.
+$obj is no longer usable after this call.
 
 =head1 INSTANCE METHODS
 
